package
Version:
v0.0.0-...-c840852
Opens a new window with list of versions in this module.
Published: May 11, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (c *LRU[K, V]) Add(key K, value V) (evicted bool)
func (c *LRU[K, V]) Get(key K) (V, bool)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.